@@ -35,11 +35,15 @@
 #include<stdint.h>
 #include<time.h>
 
+#ifdef WITH_ZLIB
+#include<zlib.h>
+#endif
+
 #include<valarray>
 #include<vector>
 #include<map>
 
-#define CDHIT_VERSION  "4.7"
+#define CDHIT_VERSION  "4.8.1"
 
 #ifndef MAX_SEQ
 #define MAX_SEQ 655360
@@ -280,10 +284,10 @@ struct Options
 	int     frag_size;
 	int     option_r;
 	int     threads;
-	int	PE_mode;     // -P
-        int     trim_len;    // -cx
-        int     trim_len_R2; // -cy
-        int     align_pos;   // -ap for alignment position
+	int     PE_mode;     // -P
+    int     trim_len;    // -cx
+    int     trim_len_R2; // -cy
+    int     align_pos;   // -ap for alignment position
 
 	size_t  max_entries;
 	size_t  max_sequences;
@@ -303,8 +307,8 @@ struct Options
 	string  output;
 	string  output_pe;
         
-        int     sort_output;  // -sc
-        int     sort_outputf; // -sf
+    int     sort_output;  // -sc
+    int     sort_outputf; // -sf
 
 	Options(){
 		backupFile = false;
@@ -342,12 +346,12 @@ struct Options
 		frag_size = 0;
 		des_len = 20;
 		threads = 1;
-                PE_mode = 0;
-                trim_len = 0;
-                trim_len_R2 = 0;
-                align_pos = 0;
-                sort_output = 0;
-                sort_outputf = 0;
+        PE_mode = 0;
+        trim_len = 0;
+        trim_len_R2 = 0;
+        align_pos = 0;
+        sort_output = 0;
+        sort_outputf = 0;
 		max_entries = 0;
 		max_sequences = 1<<20;
 		mem_limit = 100000000;
@@ -374,7 +378,7 @@ struct Sequence
 	// length of the sequence:
 	int   size;
 	int   bufsize;
-        int   size_R2; // size = size.R1 + size.R2 for back-to-back merged seq
+    int   size_R2; // size = size.R1 + size.R2 for back-to-back merged seq
 
 	//uint32_t stats;
 
@@ -387,8 +391,8 @@ struct Sequence
 
 	// stream offset of the description string in the database:
 	size_t   des_begin, des_begin2;
-        // total record length
-        int   tot_length, tot_length2;
+    // total record length
+    int   tot_length, tot_length2;
 
 	char *identifier;
 
@@ -417,7 +421,7 @@ struct Sequence
 	int Format();
 
 	void ConvertBases();
-        void trim(int trim_len);
+    void trim(int trim_len);
 
 	void SwapIn();
 	void SwapOut();
@@ -559,9 +563,17 @@ class SequenceDB
 		~SequenceDB(){ Clear(); }
 
 		void Read( const char *file, const Options & options );
+		void Readgz( const char *file, const Options & options );
+
 		void Read( const char *file, const char *file2, const Options & options );
+		void Readgz( const char *file, const char *file2, const Options & options );
+
 		void WriteClusters( const char *db, const char *newdb, const Options & options );
+		void WriteClustersgz( const char *db, const char *newdb, const Options & options );
+
 		void WriteClusters( const char *db, const char *db_pe, const char *newdb, const char *newdb_pe, const Options & options );
+		void WriteClustersgz( const char *db, const char *db_pe, const char *newdb, const char *newdb_pe, const Options & options );
+
 		void WriteExtra1D( const Options & options );
 		void WriteExtra2D( SequenceDB & other, const Options & options );
 		void DivideSave( const char *db, const char *newdb, int n, const Options & options );
